@@ -12,7 +12,7 @@ use feature ();
 package Zydeco;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.602';
+our $VERSION   = '0.603';
 
 use Keyword::Simple ();
 use PPR;
@@ -2378,9 +2378,19 @@ sub _include {
 	
 	require Path::ScanINC;
 	my @chunks = split /::/, $_[0];
-	$chunks[-1] .= '.pl';
+	$chunks[-1] .= '.zydeco.pm';
 	my $file = Path::ScanINC->new->first_file(@chunks);
 	
+	if (!$file) {
+		my @fallback = @chunks;
+		$fallback[-1] =~ s/\.zydeco\.pm$/.pl/;
+		$file = Path::ScanINC->new->first_file(@fallback);
+		if ($file) {
+			require Carp;
+			Carp::carp("Include .pl deprecated, use .zydeco.pm instead. Loaded: " . join("/", @fallback));
+		}
+	}
+	
 	if (!$file) {
 		require Carp;
 		Carp::croak("No such file: " . join("/", @chunks));
@@ -2399,7 +2409,7 @@ sub _include {
 #{
 #	package Zydeco::Anonymous::Package;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.602';
+#	our $VERSION   = '0.603';
 #	use overload q[""] => sub { ${$_[0]} }, fallback => 1;
 #	sub DESTROY {}
 #	sub AUTOLOAD {
@@ -2410,7 +2420,7 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Class;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.602';
+#	our $VERSION   = '0.603';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub new {
 #		my $me = shift;
@@ -2423,12 +2433,12 @@ sub _include {
 #	
 #	package Zydeco::Anonymous::Role;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.602';
+#	our $VERSION   = '0.603';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	
 #	package Zydeco::Anonymous::ParameterizableClass;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.602';
+#	our $VERSION   = '0.603';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -2442,7 +2452,7 @@ sub _include {
 #
 #	package Zydeco::Anonymous::ParameterizableRole;
 #	our $AUTHORITY = 'cpan:TOBYINK';
-#	our $VERSION   = '0.602';
+#	our $VERSION   = '0.603';
 #	our @ISA       = qw(Zydeco::Anonymous::Package);
 #	sub generate_package {
 #		my $me  = shift;
@@ -3003,11 +3013,11 @@ class will not be able to see functions exported into the class.
     include Classes;
   }
   
-  # MpApp/Roles.pl
+  # MyApp/Roles.zydeco.pm
   role Foo;
   role Bar;
   
-  # MyApp/Classes.pl
+  # MyApp/Classes.zydeco.pm
   class Foo::Bar with Foo, Bar;
 
 =head2 C<< Zydeco::PACKAGE_SPEC() >>
